/* mainmenu.c - functions that deal with "main menu"
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 */
#include <gtk/gtk.h>

#include "gtkballs.h"		/* new_game(), undo_move(), show_rules() */
#include "about.h"		/* about() */
#include "rules.h"		/* show_rules() */
#include "savedialog.h"		/* save/load_game_cb() */
#include "preferences.h"	/* preferences_dialog() */
#include "scoreboard.h"         /* for halloffame =/ */
#include "halloffame.h"         /* show_hall_of_fame() */
#include "rulesdialog.h"        /* rules_dialog() */

GtkItemFactory *_menu_items_factory;

static GtkItemFactoryEntry _menu_items[] =
{
	{N_("/_Game"), 		       NULL, 	     NULL, 		0, "<Branch>"},
  	{N_("/_Game/tear0"), 	       NULL, 	     NULL, 		0, "<Tearoff>"},
  	{N_("/_Game/_New"), 	       "<control>N", new_game, 		0, "<StockItem>", GTK_STOCK_NEW},
  	{N_("/_Game/_Rules"), 	       "<control>R", rules_dialog, 	0, "<StockItem>", GTK_STOCK_PROPERTIES},
  	{N_("/_Game/sep0"), 	       NULL, 	     NULL, 		0, "<Separator>"},
  	{N_("/_Game/_Save"), 	       "<control>S", save_game_cb, 	0, "<StockItem>", GTK_STOCK_SAVE},
  	{N_("/_Game/_Load"), 	       "<control>L", load_game_cb,      0, "<StockItem>", GTK_STOCK_OPEN},
  	{N_("/_Game/sep0"), 	       NULL, 	     NULL, 		0, "<Separator>"},
        {N_("/_Game/_Hall of fame"),   "<control>H", show_hall_of_fame, 0, "<Item>"},
        {N_("/_Game/sep1"), 	       NULL, 	     NULL, 		0, "<Separator>"},
  	{N_("/_Game/_Quit"), 	       "<control>Q", gtk_main_quit,     0, "<StockItem>", GTK_STOCK_QUIT},
  	{N_("/_Edit"), 	      	       NULL, 	     NULL, 		0, "<Branch>"},
  	{N_("/_Edit/tear1"),           NULL,         NULL, 		0, "<Tearoff>"},
  	{N_("/_Edit/_Undo"), 	       "<control>U", undo_move,        	0, "<StockItem>", GTK_STOCK_UNDO},
  	{N_("/_Settings"), 	       NULL, 	     NULL, 		0, "<Branch>"},
  	{N_("/_Settings/tear1"),       NULL,         NULL, 		0, "<Tearoff>"},
  	{N_("/_Settings/_Preferences"),"<control>P", preferences_dialog,0, "<StockItem>", GTK_STOCK_PREFERENCES},
  	{N_("/_Help"),                 NULL,         NULL, 		0, "<LastBranch>"},
  	{N_("/_Help/tear2"),           NULL,         NULL, 		0, "<Tearoff>"},
  	{N_("/_Help/_Rules"), 	       "F1",         show_rules, 	0, "<StockItem>", GTK_STOCK_HELP},
  	{N_("/_Help/sep2"),  	       NULL,         NULL, 		0, "<Separator>"},
  	{N_("/_Help/_About"),	       "<control>A", about, 		0, "<Item>"}
};

static gchar *_menu_translate(const gchar *path, gpointer data) {
        return gettext(path);
}

void _menu_set_sensitive(const gchar *path, gboolean sensitive) {
    GtkWidget *widget;

    g_return_if_fail(_menu_items_factory != NULL);

    widget = gtk_item_factory_get_item(_menu_items_factory, path);
    gtk_widget_set_sensitive(widget, sensitive);
}

void menu_set_sensitive_undo(gboolean sensitive) {
        _menu_set_sensitive("/Edit/Undo", sensitive);
}

void menu_get_main(GtkWidget *window, GtkWidget **menubar) {
  	gint nmenu_items;

  	nmenu_items = sizeof(_menu_items) / sizeof(_menu_items[0]);
  	_menu_items_factory = gtk_item_factory_new(GTK_TYPE_MENU_BAR, "<Main>", NULL);
  	gtk_item_factory_set_translate_func(_menu_items_factory, _menu_translate, NULL, NULL);
  	gtk_item_factory_create_items(_menu_items_factory, nmenu_items, _menu_items, NULL);
  	gtk_window_add_accel_group(GTK_WINDOW(window), _menu_items_factory->accel_group);

  	if(menubar) {
    		*menubar = _menu_items_factory->widget;
        }
}
